<?php /* 投稿一覧表示用テンプレート */ ?>

<?php /* get_header() を使ってページ共通ヘッダーテンプレートを読み込みます。 */ ?>
<?php get_header(); ?>

<?php /*
	表示する投稿一覧の種類によって「目次」のサブタイトルを変更します。

	すべての投稿一覧					// 目次
	カテゴリー別の投稿一覧				// 目次（カテゴリー：カテゴリー名）
	タグ別の投稿一覧					// 目次（タグ：タグ名）
	日付別の投稿一覧					// 目次（年月：yy年mm月）

	目次のサブタイトルを変更するためのい処理で使用している関数は、以下の通りです。

	esc_html()							// HTML のエスケープ処理
	esc_url()							// URL の無害化処理
	get_bloginfo()						// サイト情報の取得
	get_the_date()						// 投稿の日付を取得
	home_url()							// 現在のホーム URL を取得
	is_category()						// カテゴリーアーカイブページ表示中かのチェック
	is_date()							// 日付関連アーカイブページ表示中かのチェック
	is_tag()							// 投稿タグアーカイブページ表示中かのチェック
	single_cat_title()					// ページタイトル（カテゴリー名またはタグ名）の取得
	single_tag_title()					// タグタイトルの取得

*/ ?>
<?php
	$page_title = "";
	if ( is_category() ) {
		$page_title = '<span>（カテゴリー：' . single_cat_title( '', false ) . '）</span>';
	}
	else if ( is_tag() ) {
		$page_title = '<span>（タグ：' . single_tag_title( '', false ) . '）</span>';
	}
	else if ( is_date() ) {
		$page_title = '<span>（年月：' . get_the_date( "Y年n月" ) . '）</span>';
	}
?>
	<div class="top-wrapper">
		<div class="side">
			<div class="sticker">
				<div class="sticker-inner">
					<div class="sticker-inner2"></div>
				</div>
			</div>
		</div>
		<div class="note">
			<div class="inner">
				<div class="inner2">
					<div class="inner3">
						<p class="notebook">NOTE BOOK</p>
						<h1 class="title"><span><a href="<?php echo esc_url(home_url('/')); ?>"><?php echo esc_html( get_bloginfo( 'name' ) ); ?></a></span></h1>
						<p class="index">目次<?php echo $page_title; ?></p>
						<ul class="list">
<?php /*
	have_posts() は現在の WordPress クエリにループできる結果があるかどうかをチェックします。
	WordPress クエリループを処理する一般形は、以下の通りです。

	if ( have_posts() ) {				// 処理するクエリがあるかのチェック
		while ( have_posts() ) {		// 処理するクエリが無くなるまでループ
			the_post();					// 処理するクエリ情報の設定
			・・・						// 個別クエリの処理
		}
	}

	個別クエリの処理で使用している関数は、以下の通りです。

	date()								// 日付時刻の取得
	get_bloginfo()						// サイト情報の取得
	get_permalink()						// 投稿のパーマリンクを取得
	get_the_title()						// 投稿のタイトルを取得
	get_the_date()						// 投稿の日付を取得
	get_the_author()					// 投稿の投稿者名を取得
	get_the_posts_pagination			// 投稿の前と次のページ番号セットを取得

*/ ?>
<?php
if ( have_posts() ) {
	while ( have_posts() ) {
		the_post();
		$permalink = esc_url( get_permalink() );		// URL
		$title = get_the_title();						// タイトル
		$date = get_the_date( 'Y.m.d' );				// 投稿日付
		$author = get_the_author();						// 投稿者
?>
							<li><a href="<?php echo $permalink; ?>" class="blog-item"><?php echo $title; ?><span>（<?php echo $date; ?>／<?php echo $author; ?>）</span></a></li>
<?php
	}
?>
						</ul>
					</div>
<?php
		$pagination = get_the_posts_pagination( array(	// ページネーションを取得
			'mid_size'  => 2,							// 現在のページの左右に表示するページ番号の数
			'prev_text' => __('Previous'),				// 前のセットへのリンクテキスト
			'next_text' => __('Next')					// 次のセットへのリンクテキスト
		) );
		if ($pagination == '') {
			$pagination = '<nav class="navigation pagination" aria-label="投稿"><h2 class="screen-reader-text"></h2><div class="nav-links"><span aria-current="page" class="page-numbers current"> </span></div></nav>';
		}
		echo $pagination . PHP_EOL;
?>
					<footer>
						<p><?php echo sprintf( '<small>&copy; %1$s %2$s.</small>', date( 'Y' ), get_bloginfo( 'name' ) ); ?></p>
					</footer>
				</div>
			</div>
		</div>
<?php
}
?>

<?php /* get_footer() を使ってページ共通フッターテンプレートを読み込みます。 */ ?>
<?php get_footer(); ?>
