<?php /* 固定ページ用テンプレート */ ?>

<?php /* get_header() を使ってページ共通ヘッダーテンプレートを読み込みます。 */ ?>
<?php get_header(); ?>

<?php /*
	have_posts() は現在の WordPress クエリにループできる結果があるかどうかをチェックします。
	WordPress クエリループを処理する一般形は、以下の通りです。

	if ( have_posts() ) {				// 処理するクエリがあるかのチェック
		while ( have_posts() ) {		// 処理するクエリが無くなるまでループ
			the_post();					// 処理するクエリ情報の設定
			・・・						// 個別クエリの処理
		}
	}

	個別クエリの処理で使用している関数は、以下の通りです。

	date()								// 現在の日付時刻を取得
	get_bloginfo()						// サイト情報を取得
	get_the_title()						// 投稿のタイトルを取得
	get_the_date()						// 投稿の日付を取得
	the_content()						// 投稿の本文を表示
	wp_link_pages()						// ページ分割された投稿ページリンクを表示

*/ ?>
<?php
if ( have_posts() ) {
	while ( have_posts() ) {
		the_post();
		$title = get_the_title();						// タイトル
		$date = get_the_date( 'Y.m.d' );				// 投稿日付
?>
	<div class="wrapper">
		<div class="note">
			<header>
				<p class="category"></p>
				<p class="date"><span>Date.</span><?php echo $date; ?></p>
				<h1><?php echo $title; ?></h1>
			</header>
			<main>
				<?php the_content(); ?>
			</main>
<?php
		wp_link_pages( array(							// 改ページ（複数ページ）処理
			'before'           => '<div class="blog-pages-pagination">',
			'after'            => '</div>' . PHP_EOL,	// before/afterは、前後に付加する文字
			'link_before'      => '',					// リンクテキストの前に負荷する文字
			'link_after'       => '',					// リンクテキストの後ろに負荷する文字
			'next_or_number'   => 'number',				// 'number'：ページ番号、'next'：前／次ページ
			'separator'        => ' ',					// ページ番号間の文字
			'nextpagelink'     => __( 'Next page' ),	// 次のページのリンクテキスト
			'previouspagelink' => __( 'Previous page' ),// 前のページのリンクテキスト
			'pagelink'         => 'ページ %',			// ページ番号のフォーマット（%はページ番号）
			'echo'             => true,					// true：表示、false：返却
		) );
?>
			<div class="blog-single_pagination">
				<p></p>
				<p></p>
			</div>
			<footer>
				<p><?php echo sprintf( '<small>&copy; %1$s %2$s.</small>', date( 'Y' ), get_bloginfo( 'name' ) ); ?></p>
			</footer>
		</div>
<?php
	}
}
?>

<?php /* get_footer(); を使ってページ共通フッターテンプレートを読み込みます。 */ ?>
<?php get_footer(); ?>
